Circonus
========

A Python module for interacting with the `Circonus`_ `REST API`_.

.. image:: https://pypip.in/v/circonus/badge.png?style=flat
   :target: https://pypi.python.org/pypi/circonus
   :alt: Latest release

.. image:: https://api.travis-ci.org/monetate/circonus.png?branch=master
   :target: https://travis-ci.org/monetate/circonus
   :alt: Travis CI build status

.. image:: https://img.shields.io/coveralls/monetate/circonus.png?style=flat
   :target: https://coveralls.io/r/monetate/circonus
   :alt: Coveralls test coverage

.. image:: https://readthedocs.org/projects/circonus/badge/?version=latest
   :target: http://circonus.readthedocs.org/en/latest/
   :alt: Documentation Status

Documentation
-------------

Available at http://circonus.readthedocs.org

.. _Circonus: http://www.circonus.com/
.. _REST API: https://login.circonus.com/resources/api
